@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: lpd.c,v 1.57 2003/09/05 20:07:19 papowell Exp $";
+"$Id: lpd.c,v 1.71 2004/05/03 20:24:02 papowell Exp $";
 
 
 #include "lp.h"
@@ -34,7 +34,8 @@
 
 #include "lpd.h"
 
- char* Lpd_listen_port_arg;	/* command line listent port value */
+ char* Lpd_listen_port_arg;	/* command line listen port value */
+ char* Ipp_listen_port_arg;	/* command line listen port value */
  char* Lpd_port_arg;	/* command line port value */
  char* Lpd_socket_arg; /* command line unix socket value */
 
@@ -61,13 +62,14 @@
  *
  ****************************************************************************/
 
+	static char *malloc_area;
 
 int main(int argc, char *argv[], char *envp[])
 {
 	int sock = 0;		/* socket for listen */
 	int pid;			/* pid */
 	fd_set defreadfds, readfds;	/* for select() */
-	int max_socks;		/* maximum number of sockets */
+	int max_socks = 0;		/* maximum number of sockets */
 	int lockfd;	/* the lock file descriptor */
 	int err, newsock;
  	time_t last_time;	/* time that last Start_all was done */
@@ -82,6 +84,7 @@ int main(int argc, char *argv[], char *envp[])
 	struct sockaddr sinaddr;
 	int first_scan = 1;
 	int unix_sock = 0;
+	int ipp_sock = 0;
 	int fd_available;
 
 	Init_line_list( &args );
@@ -211,6 +214,19 @@ int main(int argc, char *argv[], char *envp[])
 				Errorcode = 1;
 				DIEMSG("Cannot bind to lpd port '%s'", s);
 			}
+			if( sock >= max_socks ) max_socks = sock;
+		}
+
+		s = Ipp_listen_port_arg;
+		if( ISNULL(s) ) s = Ipp_listen_port_DYN;
+		if( !ISNULL(s) && safestrcasecmp( s,"off") && strtol(s,0,0) ){
+			ipp_sock = Link_listen(s);
+			DEBUG1("lpd: listening socket fd %d",ipp_sock);
+			if( ipp_sock < 0 ){
+				Errorcode = 1;
+				DIEMSG("Cannot bind to lpd port '%s'", s);
+			}
+			if( ipp_sock >= max_socks ) max_socks = ipp_sock;
 		}
 
 		s = Lpd_socket_arg;
@@ -222,6 +238,7 @@ int main(int argc, char *argv[], char *envp[])
 				Errorcode = 1;
 				DIEMSG("Cannot bind to UNIX socket '%s'", s );
 			}
+			if( unix_sock >= max_socks ) max_socks = unix_sock;
 		}
 	}
 
@@ -319,6 +336,7 @@ int main(int argc, char *argv[], char *envp[])
 	FD_ZERO( &defreadfds );
 	if( sock > 0 ) FD_SET( sock, &defreadfds );
 	if( unix_sock > 0 ) FD_SET( unix_sock, &defreadfds );
+	if( ipp_sock > 0 ) FD_SET( ipp_sock, &defreadfds );
 	FD_SET( request_pipe[0], &defreadfds );
 
 	/*
@@ -334,23 +352,53 @@ int main(int argc, char *argv[], char *envp[])
 		first_scan = 0;
 	}
 
+	malloc_area = sbrk(0);
+
+#ifdef DMALLOC
+	DEBUG1( "lpd: LOOP START - sbrk 0x%lx", (long)malloc_area );
+	{
+		extern int dmalloc_outfile_fd;
+		char buffer[128];
+		SNPRINTF(buffer,sizeof(buffer)) "lpd: LOOP START - sbrk 0x%lx\n", (long)malloc_area );
+		Write_fd_str(dmalloc_outfile_fd, buffer );
+		dmalloc_log_unfreed();
+	}
+#endif
+
+
 	do{
 		struct timeval timeval, *timeout;
 		time_t this_time = time( (void *)0 );
 		int elapsed_time;
 
+#ifdef DMALLOC
+		/* check for memory leaks */
+		{
+			char *s = sbrk(0);
+			int n = s - malloc_area;
+			DEBUG1("lpd: LOOP - sbrk 0x%lx", (long)s );
+			if( n > 1024 ){
+				extern int dmalloc_outfile_fd;
+				char buffer[128];
+				SNPRINTF(buffer,sizeof(buffer)) "lpd: LOOP sbrk reports 0x%lx, or %d more memory\n", (long)s, n );
+				Write_fd_str(dmalloc_outfile_fd, buffer );
+				dmalloc_log_unfreed();
+				DEBUG1( "lpd: LOOP sbrk reports 0x%lx, or %d more memory", (long)s, n );
+				malloc_area += n;
+			}
+		}
+#endif
+
 		/* set up the timeout values */
 
 		timeout = 0;
 		memset(&timeval, 0, sizeof(timeval));
-
-		DEBUG1("lpd: LOOP START");
 		if(DEBUGL3){ int fd; fd = dup(0); LOGDEBUG("lpd: next fd %d",fd); close(fd); };
 
 		DEBUG2( "lpd: Poll_time %d, Force_poll %d, start_pid %d, start_fd %d, Started_server %d",
 			Poll_time_DYN, Force_poll_DYN, start_pid, start_fd, Started_server );
 
-		if(DEBUGL2)Dump_line_list("lpd - Servers_line_list",&Servers_line_list );
+		if(DEBUGL1)Dump_line_list("lpd - Servers_line_list",&Servers_line_list );
 
 		/*
 		 * collect zombies.  If one exits, you can set last_fork_pid_value
@@ -450,6 +498,25 @@ int main(int argc, char *argv[], char *envp[])
 				}
 				server_to_start = 0;
 			}
+
+#ifdef DMALLOC
+			/* check for memory leaks */
+			{
+				char *s = sbrk(0);
+				int n = s - malloc_area;
+				DEBUG1("lpd: BEFORE POLL SERVICE - sbrk 0x%lx, cnt %d", (long)s, Servers_line_list.count );
+				if( n > 1024 ){
+					extern int dmalloc_outfile_fd;
+					char buffer[128];
+					SNPRINTF(buffer,sizeof(buffer)) "lpd: BEFORE POLL SERVICE sbrk reports 0x%lx, or %d more memory\n", (long)s, n );
+					Write_fd_str(dmalloc_outfile_fd, buffer );
+					dmalloc_log_unfreed();
+					DEBUG1( "lpd: BEFORE POLL SERVICE sbrk reports 0x%lx, or %d more memory", (long)s, n );
+					malloc_area += n;
+				}
+			}
+#endif
+
 			while( (elapsed_time > Poll_start_interval_DYN || forced_start )
 				&& Servers_line_list.count > 0 && server_processes_started < Poll_servers_started_DYN
 				&& number_of_servers + server_processes_started < max_servers-4 ){
@@ -497,6 +564,25 @@ int main(int argc, char *argv[], char *envp[])
 					Remove_line_list( &Servers_line_list, doit );
 				}
 			}
+
+#ifdef DMALLOC
+			/* check for memory leaks */
+			{
+				char *s = sbrk(0);
+				int n = s - malloc_area;
+				DEBUG1("lpd: AFTER POLL SERVICE - sbrk 0x%lx, cnt %d", (long)s, Servers_line_list.count );
+				if( n > 1024 ){
+					extern int dmalloc_outfile_fd;
+					char buffer[128];
+					SNPRINTF(buffer,sizeof(buffer)) "lpd: AFTER POLL SERVICE sbrk reports 0x%lx, or %d more memory\n", (long)s, n );
+					Write_fd_str(dmalloc_outfile_fd, buffer );
+					dmalloc_log_unfreed();
+					DEBUG1( "lpd: AFTER POLL SERVICE sbrk reports 0x%lx, or %d more memory", (long)s, n );
+					malloc_area += n;
+				}
+			}
+#endif
+
 		}
 		/* we see if we have any work to do
 		 * and then schedule a timeout if necessary to start a process
@@ -528,11 +614,11 @@ int main(int argc, char *argv[], char *envp[])
 			DEBUG1( "lpd: not accepting requests" );
 			if( sock > 0 ) FD_CLR( sock, &readfds );
 			if( unix_sock > 0 ) FD_CLR( unix_sock, &readfds );
+			if( ipp_sock > 0 ) FD_CLR( ipp_sock, &readfds );
 			timeval.tv_sec = 10;
 			timeout = &timeval;
 		}
 
-		max_socks = sock+1;
 		if( request_pipe[0] >= max_socks ){
 			max_socks = request_pipe[0]+1;
 		}
@@ -565,7 +651,7 @@ int main(int argc, char *argv[], char *envp[])
 			int i;
 			LOGDEBUG( "lpd: select returned %d, error '%s'",
 				fd_available, Errormsg(err) );
-			for(i=0; i < max_socks; ++i ){
+			for(i=0; fd_available > 0 && i < max_socks; ++i ){
 				if( FD_ISSET( i, &readfds ) ){
 					LOGDEBUG( "lpd: fd %d readable", i );
 				}
@@ -597,103 +683,16 @@ int main(int argc, char *argv[], char *envp[])
 			continue;
 		}
 		if( sock > 0 && FD_ISSET( sock, &readfds ) ){
-#if defined(HAVE_SOCKLEN_T)
-			socklen_t len;
-#else
-			int len;
-#endif
-			len = sizeof( sinaddr );
-			newsock = accept( sock, &sinaddr, &len );
-			err = errno;
-			DEBUG1("lpd: connection fd %d", newsock );
-			if( newsock > 0 ){
-#if defined(TCPWRAPPERS)
-/*
- * libwrap/tcp_wrappers:
- * draht@suse.de, Mon Jan 28 2002
- */
-
-			    struct request_info wrap_req;
-
-			    request_init(&wrap_req, RQ_DAEMON, "lpd" , RQ_FILE, newsock, NULL);
-			    fromhost(&wrap_req);
-			    openlog("lpd", LOG_PID, LOG_LPR); /* we syslog(3) initialized, no closelog(). */
-			    if (hosts_access(&wrap_req)) {
-				/* We accept. */
-				syslog(LOG_INFO, "connection from %s", eval_client(&wrap_req));
-#endif
-
-				pid = Start_worker( "server", &args, newsock );
-				if( pid < 0 ){
-					LOGERR(LOG_INFO) _("lpd: fork() failed") );
-					Write_fd_str( newsock, "\002Server load too high\n");
-				} else {
-					DEBUG1( "lpd: listener pid %d running", pid );
-				}
-#if defined(TCPWRAPPERS)
-			    } else { /* we do not accept the connection: */
-				syslog(LOG_WARNING, "connection refused from %s", eval_client(&wrap_req));
-			    }
-/* 
- * end libwrap
- */
-#endif
-				close( newsock );
-				Free_line_list(&args);
-			} else {
-				errno = err;
-				LOGERR(LOG_INFO) _("lpd: accept on listening socket failed") );
-			}
+			DEBUG1("lpd: accept on LPD socket");
+			Accept_connection( sock, 0, 0 );
 		}
 		if( unix_sock > 0 && FD_ISSET( unix_sock, &readfds ) ){
-#if defined(HAVE_SOCKLEN_T)
-			socklen_t len;
-#else
-			int len;
-#endif
-			len = sizeof( sinaddr );
-			newsock = accept( unix_sock, &sinaddr, &len );
-			err = errno;
-			DEBUG1("lpd: unix socket connection fd %d", newsock );
-			if( newsock > 0 ){
-#if defined(TCPWRAPPERS)
-/*
- * libwrap/tcp_wrappers:
- * draht@suse.de, Mon Jan 28 2002
- */
-
-			    struct request_info wrap_req;
-
-			    request_init(&wrap_req, RQ_DAEMON, "lpd" , RQ_FILE, newsock, NULL);
-			    fromhost(&wrap_req);
-			    openlog("lpd", LOG_PID, LOG_LPR); /* we syslog(3) initialized, no closelog(). */
-			    if (hosts_access(&wrap_req)) {
-				/* We accept. */
-				syslog(LOG_INFO, "connection from %s", eval_client(&wrap_req));
-#endif
-
-				pid = Start_worker( "server", &args, newsock );
-				if( pid < 0 ){
-					LOGERR(LOG_INFO) _("lpd: fork() failed") );
-					Write_fd_str( newsock, "\002Server load too high\n");
-				} else {
-					DEBUG1( "lpd: listener pid %d running", pid );
-				}
-#if defined(TCPWRAPPERS)
-			    } else { /* we do not accept the connection: */
-				syslog(LOG_WARNING, "connection refused from %s", eval_client(&wrap_req));
-			    }
-/* 
- * end libwrap
- */
-#endif
-
-				close( newsock );
-				Free_line_list(&args);
-			} else {
-				errno = err;
-				LOGERR(LOG_INFO) _("lpd: accept on listening socket failed") );
-			}
+			DEBUG1("lpd: accept on UNIX socket");
+			Accept_connection( unix_sock, 0, 1 );
+		}
+		if( ipp_sock > 0 && FD_ISSET( ipp_sock, &readfds ) ){
+			DEBUG1("lpd: accept on IPP socket");
+			Accept_connection( ipp_sock, 0, 0 );
 		}
 		if( FD_ISSET( request_pipe[0], &readfds ) 
 			&& Read_server_status( request_pipe[0] ) == 0 ){
@@ -850,7 +849,7 @@ int Read_server_status( int fd )
 			fd = 0;
 			break;
 		}
-		status = read(fd,buffer,sizeof(buffer)-1);
+		status = ok_read(fd,buffer,sizeof(buffer)-1);
 		DEBUG1( "Read_server_status: read status %d", status );
 		if( status <= 0 ){
 			close(fd);
@@ -863,6 +862,7 @@ int Read_server_status( int fd )
 		if(DEBUGL1)Dump_line_list("Read_server_status - input", &l );
 		for( count = 0; count < l.count; ++count ){ 
 			name = l.list[count];
+			if( ISNULL(name) ) continue;
 			found = 0;
 			for( n = 0;!found && n < Servers_line_list.count; ++n ){
 				found = !safestrcasecmp( Servers_line_list.list[n], name);
@@ -872,7 +872,27 @@ int Read_server_status( int fd )
 			}
 			Started_server = 1;
 		}
+		Free_line_list(&l);
 	}
+	Free_line_list(&l);
+
+#ifdef DMALLOC
+	{
+		char *s = sbrk(0);
+		int n = s - malloc_area;
+		DEBUG1("lpd: READ_SERVER_STATUS - sbrk 0x%lx, cnt %d", (long)s, Servers_line_list.count );
+		if( n > 1024 ){
+			extern int dmalloc_outfile_fd;
+			char buffer[128];
+			SNPRINTF(buffer,sizeof(buffer)) "lpd: READ_SERVER_STATSUS sbrk reports 0x%lx, or %d more memory\n", (long)s, n );
+			Write_fd_str(dmalloc_outfile_fd, buffer );
+			dmalloc_log_unfreed();
+			DEBUG1( "lpd: READ_SERVER_STATUS sbrk reports 0x%lx, or %d more memory", (long)s, n );
+			malloc_area += n;
+		}
+	}
+#endif
+
 	if(DEBUGL2)Dump_line_list("Read_server_status - waiting for start",
 			&Servers_line_list );
 	return(fd);
@@ -942,7 +962,68 @@ void Get_parms(int argc, char *argv[] )
 	}
 }
 
+
 /*
+ * Accept_connection
+ *   - accept the connection and fork the child to handle it
+ */
+void Accept_connection( int sock, int lpd_socket, int unix_socket )
+{ 
+	struct line_list args;
+	struct sockaddr sinaddr;
+	int newsock, err, pid;
+#if defined(HAVE_SOCKLEN_T)
+	socklen_t len;
+#else
+	int len;
+#endif
+	Init_line_list(&args);
+	len = sizeof( sinaddr );
+	newsock = accept( sock, &sinaddr, &len );
+	err = errno;
+	DEBUG1("Accept_connection: connection fd %d", newsock );
+	if( newsock > 0 ){
+#if defined(TCPWRAPPERS)
+/*
+* libwrap/tcp_wrappers:
+* draht@suse.de, Mon Jan 28 2002
+*/
+		if( !unix_socket ){
+			struct request_info wrap_req;
+
+			request_init(&wrap_req, RQ_DAEMON, "lpd" , RQ_FILE, newsock, NULL);
+			fromhost(&wrap_req);
+			openlog("lpd", LOG_PID, LOG_LPR); /* we syslog(3) initialized, no closelog(). */
+			if (hosts_access(&wrap_req)) {
+				/* We accept. */
+				syslog(LOG_INFO, "connection from %s", eval_client(&wrap_req));
+			} else {
+				syslog(LOG_WARNING, "connection refused from %s", eval_client(&wrap_req));
+				close( newsock );
+				return;
+			}
+		}
+#endif
+
+		pid = Start_worker( "server", &args, newsock );
+		if( pid < 0 ){
+			LOGERR(LOG_INFO) _("lpd: fork() failed") );
+			if( lpd_socket ){
+				Write_fd_str( newsock, "\002Server load too high\n");
+			}
+		} else {
+			DEBUG1( "lpd: listener pid %d running", pid );
+		}
+		close( newsock );
+		Free_line_list(&args);
+	} else {
+		errno = err;
+		LOGERR(LOG_INFO) _("lpd: accept on listening socket failed") );
+	}
+}
+
+/*
+ * int Start_all( int first_scan, int *start_fd )
  * returns the pid of the process doing the scanning
  */
  
