@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: lpd_status.c,v 1.57 2003/09/05 20:07:19 papowell Exp $";
+"$Id: lpd_status.c,v 1.71 2004/05/03 20:24:03 papowell Exp $";
 
 
 #include "lp.h"
@@ -127,9 +127,9 @@ int Job_status( int *sock, char *input )
 		Split(&listv,Force_lpq_status_DYN,";",0,0,0,0,0,0);
 		for(i = 0; i < listv.count; ++i ){
 			s = listv.list[i];
-			if( (t = safestrpbrk(s,File_sep)) ) *t++ = 0;
+			if( (t = safestrpbrk(s,Hash_value_sep)) ) *t++ = 0;
 			Free_line_list(&l);
-			Split(&l,t,Value_sep,0,0,0,0,0,0);
+			Split(&l,t,File_sep,0,0,0,0,0,0);
 			DEBUGF(DLPQ1)("Job_status: Force_lpq_status '%s'='%s'", s,t);
 			if( Match_ipaddr_value( &l, &RemoteHost_IP ) == 0 ){
 				DEBUGF(DLPQ1)("Job_status: forcing status '%s'", s);
@@ -198,10 +198,10 @@ int Job_status( int *sock, char *input )
 	if( l.count && (s = l.list[0]) && s[0] == '-' ){
 		DEBUGF(DLPQ1)("Job_status: arg '%s'", s );
 		Free_line_list(&listv);
-		Split(&listv,s+1,Arg_sep,1,Value_sep,1,1,0,0);
+		Split(&listv,s+1,Arg_sep,1,Hash_value_sep,1,1,0,0);
 		Remove_line_list( &l, 0 );
 		DEBUGFC(DLPQ1)Dump_line_list( "Job_status: args", &listv );
-		if( (n = Find_flag_value(&listv,"lines",Value_sep)) ) status_lines = n;
+		if( (n = Find_flag_value(&listv,"lines")) ) status_lines = n;
 		DEBUGF(DLPQ1)("Job_status: status_lines '%d'", status_lines );
 		Free_line_list(&listv);
 	}
@@ -314,7 +314,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 
 	db = Debug;
 	dbflag = DbgFlag;
-	s = Find_str_value(&Spool_control,DEBUG,Value_sep);
+	s = Find_str_value(&Spool_control,DEBUG);
 	if( !s ) s = New_debug_DYN;
 	Parse_debug( s, 0 );
 	if( !(DLPQMASK & DbgFlag) ){
@@ -341,10 +341,10 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 
 	DEBUGF(DLPQ3)("Get_queue_status: sock fd %d, Setup_printer status %d '%s'", *sock, status, error );
 	/* set up status */
-	if( Find_exists_value(done_list,Printer_DYN,Value_sep ) ){
+	if( Find_exists_value(done_list,Printer_DYN,Hash_value_sep ) ){
 		return;
 	}
-	Add_line_list(done_list,Printer_DYN,Value_sep,1,1);
+	Add_line_list(done_list,Printer_DYN,Hash_value_sep,1,1);
 
 	/* check for permissions */
 
@@ -406,8 +406,8 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 		DEBUGF(DLPQ3)("Get_queue_status: found in cache '%s'", file );
 		fd = -1;
 		if( file ){
-			Split(&cache_info,file,Arg_sep,1,Value_sep,1,1,0,0);
-			file = Find_str_value(&cache_info,FILENAMES,Value_sep);
+			Split(&cache_info,file,Arg_sep,1,Hash_value_sep,1,1,0,0);
+			file = Find_str_value(&cache_info,FILENAMES);
 		}
 		DEBUGFC(DLPQ3)Dump_line_list("Get_queue_status: cache_info", &cache_info );
 		if( file && (fd = Checkread( file, &statb )) > 0 ){
@@ -423,7 +423,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 			if( Queue_status_file_DYN && stat(Queue_status_file_DYN,&statb) == 0 ){
 				modified = statb.st_mtime;
 			}
-			timestamp = Find_flag_value(&cache_info,QUEUE_STATUS_FILE,Value_sep);
+			timestamp = Find_flag_value(&cache_info,QUEUE_STATUS_FILE);
 			delta = modified - timestamp;
 			DEBUGF(DLPQ3)("Get_queue_status: queue status '%s', modified %lx, timestamp %lx, delta %d",
 				Queue_status_file_DYN, (long)(modified), (long)(timestamp), delta );
@@ -437,7 +437,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 			if( Status_file_DYN && stat(Status_file_DYN,&statb) == 0 ){
 				modified = statb.st_mtime;
 			}
-			timestamp = Find_flag_value(&cache_info,PRSTATUS,Value_sep);
+			timestamp = Find_flag_value(&cache_info,PRSTATUS);
 			delta = modified - timestamp;
 			DEBUGF(DLPQ3)("Get_queue_status: pr status '%s', modified %lx, timestamp %lx, delta %d",
 				Status_file_DYN, (long)(modified), (long)(timestamp), delta );
@@ -450,7 +450,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 		if( fd > 0 ){
 			DEBUGF(DLPQ3)("Get_queue_status: reading cached status from fd '%d'", fd );
 			/* We can read the status from the cached data */
-			while( (ix = read( fd, buffer, sizeof(buffer)-1 )) > 0 ){
+			while( (ix = ok_read( fd, buffer, sizeof(buffer)-1 )) > 0 ){
 				if( write( *sock, buffer, ix ) < 0 ){
 					cleanup(0);
 				}
@@ -527,7 +527,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 		 Rank  Owner/ID  Class Job Files   Size Time
 		*/
 		Add_line_list(&outbuf,
-" Rank   Owner/ID                  Class Job Files                 Size Time"
+" Rank   Owner/ID               Pr/Class Job Files                 Size Time"
 		,0,0,0);
 	}
 	error[0] = 0;
@@ -537,9 +537,14 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 	total_move = 0;
 	for( count = 0; count < Sort_order.count; ++count ){
 		int printable, held, move;
+		char prclass[32];
 		printable = held = move = 0;
 		Free_job(&job);
-		Get_hold_file(&job, Sort_order.list[count] );
+		Get_hold_file(&job, Sort_order.list[count], 0 );
+		if( job.info.count == 0 ){
+			/* job was removed */
+			continue;
+		}
 		Job_printable(&job,&Spool_control, &printable,&held,&move,&jerror,&jdone);
 		DEBUGF(DLPQ3)("Get_queue_status: printable %d, held %d, move %d, error %d, done %d",
 			printable, held, move, jerror, jdone );
@@ -554,42 +559,30 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 		error[0] = 0;
 		msg[0] = 0;
 		nodest = 0;
-		s = Find_str_value(&job.info,PRSTATUS,Value_sep);
+		s = Find_str_value(&job.info,PRSTATUS);
 		if( s == 0 ){
 			SNPRINTF(number,sizeof(number))"%d",count+1);
 		} else {
 			SNPRINTF(number,sizeof(number))"%s",s);
 		}
-		identifier = Find_str_value(&job.info,IDENTIFIER,Value_sep);
+		identifier = Find_str_value(&job.info,IDENTIFIER);
 		if( identifier == 0 ){
-			identifier = Find_str_value(&job.info,LOGNAME,Value_sep);
+			identifier = Find_str_value(&job.info,LOGNAME);
 		}
 		if( identifier == 0 ){
 			identifier = "???";
 		}
-		priority = Find_str_value(&job.info,PRIORITY,Value_sep);
-		class = Find_str_value(&job.info,CLASS,Value_sep);
-		jobname = Find_str_value(&job.info,JOBNAME,Value_sep);
-		filenames = Find_str_value(&job.info,FILENAMES,Value_sep);
-		jobnumber = Find_decimal_value(&job.info,NUMBER,Value_sep);
-		joberror = Find_str_value(&job.info,ERROR,Value_sep);
-		jobsize = Find_double_value(&job.info,SIZE,Value_sep);
-		job_time = Find_str_value(&job.info,JOB_TIME,Value_sep );
-		destinations = Find_flag_value(&job.info,DESTINATIONS,Value_sep);
-
-		openname = Find_str_value(&job.info,OPENNAME,Value_sep);
-		if( !openname ){
-			openname = Find_str_value(&job.info,TRANSFERNAME,Value_sep);
-		}
-		if( !openname ){
-			DEBUGF(DLPQ4)("Get_queue_status: no openname or transfername");
-			continue;
-		}
-		hf_name = Find_str_value(&job.info,HF_NAME,Value_sep);
-		if( !hf_name ){
-			DEBUGF(DLPQ4)("Get_queue_status: no hf_name");
-			continue;
-		}
+		priority = Find_str_value(&job.info,PRIORITY);
+		class = Find_str_value(&job.info,CLASS);
+		jobname = Find_str_value(&job.info,JOBNAME);
+		filenames = Find_str_value(&job.info,FILENAMES);
+		jobnumber = Find_decimal_value(&job.info,NUMBER);
+		joberror = Find_str_value(&job.info,ERROR);
+		jobsize = Find_double_value(&job.info,SIZE);
+		job_time = Find_str_value(&job.info,JOB_TIME );
+		destinations = Find_flag_value(&job.info,DESTINATIONS);
+		openname = Find_str_value(&job.info,CFTRANSFERNAME);
+		hf_name = Find_str_value(&job.info,HF_NAME);
 
 		/* we report this jobs status */
 
@@ -597,8 +590,13 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 		DEBUGF(DLPQ3)("Get_queue_status: class '%s', priority '%s'",
 			class, priority );
 
-		if( (Class_in_status_DYN && class) || priority == 0 ){
-			priority = class;
+		if( class ){
+			if( safestrcmp(class,priority)
+				|| Class_in_status_DYN || priority == 0 ){
+				SNPRINTF( prclass, sizeof(prclass)) "%s/%s",
+					priority?priority:"?", class );
+				priority = prclass;
+			}
 		}
 
 		if( displayformat == REQ_DLONG ){
@@ -647,21 +645,18 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 					SNPRINTF(msg+len,sizeof(msg)-len)
 					"ERROR: %s", joberror );
 			} else {
+				char jobb[32];
 				DEBUGF(DLPQ3)("Get_queue_status: jobname '%s'", jobname );
 
 				len = safestrlen(msg);
 				SNPRINTF(msg+len,sizeof(msg)-len)"%-s",jobname?jobname:filenames);
+				SNPRINTF(jobb,sizeof(jobb)) "%0.0f", jobsize );
 
-				DEBUGF(DLPQ3)("Get_queue_status: jobtime '%s'", job_time );
 				job_time = Time_str(1, Convert_to_time_t(job_time));
-				if( !Full_time_DYN && (s = safestrchr(job_time,'.')) ) *s = 0;
-
-				{
-					char jobb[32];
-					SNPRINTF(jobb,sizeof(jobb)) "%0.0f", jobsize );
-					SNPRINTF( sizestr, sizeof(sizestr)) "%*s %-s",
-						SIZEW-1,jobb, job_time );
-				}
+				if( !Full_time_DYN && (t = safestrchr(job_time,'.')) ) *t = 0;
+				SNPRINTF( sizestr, sizeof(sizestr)) "%*s %-s",
+					SIZEW-1,jobb, job_time );
+				DEBUGF(DLPQ3)("XGet_queue_status: size_str '%s'",sizestr);
 
 				len = Max_status_line_DYN;
 				if( len >= (int)sizeof(msg)) len = sizeof(msg)-1;
@@ -705,16 +700,16 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 					DEBUGFC(DLPQ3)Dump_line_list("Get_queue_status: destination",
 						&job.destination);
 					d_error =
-						Find_str_value(&job.destination,ERROR,Value_sep);
+						Find_str_value(&job.destination,ERROR);
 					d_dest =
-						Find_str_value(&job.destination,DEST,Value_sep);
+						Find_str_value(&job.destination,DEST);
 					d_copies = 
-						Find_flag_value(&job.destination,COPIES,Value_sep);
+						Find_flag_value(&job.destination,COPIES);
 					d_copy_done = 
-						Find_flag_value(&job.destination,COPY_DONE,Value_sep);
+						Find_flag_value(&job.destination,COPY_DONE);
 					d_identifier =
-						Find_str_value(&job.destination,IDENTIFIER,Value_sep);
-					s = Find_str_value(&job.destination, PRSTATUS,Value_sep);
+						Find_str_value(&job.destination,IDENTIFIER);
+					s = Find_str_value(&job.destination, PRSTATUS);
 					if( !s ) s = "";
 					SNPRINTF(number, sizeof(number))" - %-8s", s );
 					SNPRINTF( msg, sizeof(msg))
@@ -751,15 +746,16 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 						header, joberror );
 				Add_line_list(&outbuf,msg,0,0,0);
 			}
-			SNPRINTF( msg, sizeof(msg)) _("%s CONTROL="), header );
-			Add_line_list(&outbuf,msg,0,0,0);
-			s = Get_file_image(openname,0);
-			Add_line_list(&outbuf,s,0,0,0);
-			if( s ) free(s); s = 0;
+			if( openname ){
+				SNPRINTF( msg, sizeof(msg)) _("%s CONTROL="), header );
+				Add_line_list(&outbuf,msg,0,0,0);
+				s = Find_str_value(&job.info,CF_OUT_IMAGE);
+				Add_line_list(&outbuf,s,0,0,0);
+			}
 
 			SNPRINTF( msg, sizeof(msg)) _("%s HOLDFILE="), header );
 			Add_line_list(&outbuf,msg,0,0,0);
-			s = Get_file_image(hf_name,0);
+			s = Make_hf_image(&job);
 			Add_line_list(&outbuf,s,0,0,0);
 			if( s ) free(s); s = 0;
 		} else if( displayformat == REQ_DSHORT ){
@@ -945,7 +941,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 		}
 	}
 
-	if( (s = Find_str_value( &Spool_control,MSG,Value_sep )) ){
+	if( (s = Find_str_value( &Spool_control,MSG )) ){
 		len = safestrlen( header );
 		if( displayformat == REQ_VERBOSE ){
 			SNPRINTF( header+len, sizeof(header)-len)
@@ -1064,7 +1060,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 			LOGERR_DIE(LOG_INFO)"Get_queue_status: lseek of '%s' failed",
 				tempfile );
 		}
-		while( (ix = read( tempfd, buffer, sizeof(buffer)-1 )) > 0 ){
+		while( (ix = ok_read( tempfd, buffer, sizeof(buffer)-1 )) > 0 ){
 			if( write( *sock, buffer, ix ) < 0 ){
 				break;
 			}
@@ -1081,8 +1077,8 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 			DEBUGF(DLPQ3)("Get_queue_status: [%d] '%s'", ix, s );
 			Free_line_list(&cache_info);
 			if( s && (t = strchr(s,'=')) ){
-				Split(&cache_info,t+1,Arg_sep,1,Value_sep,1,1,0,0);
-				if( (file = Find_str_value(&cache_info,FILENAMES,Value_sep)) ){
+				Split(&cache_info,t+1,Arg_sep,1,Hash_value_sep,1,1,0,0);
+				if( (file = Find_str_value(&cache_info,FILENAMES)) ){
 					/* we need to get the age of the file */
 					if( stat( file,&statb ) ){
 						/* the file is not there */
@@ -1228,7 +1224,7 @@ void Get_queue_status( struct line_list *tokens, int *sock,
 					char *tempfile;
 					/* shutdown( fd, 1 ); */
 					tempfd = Make_temp_fd( &tempfile );
-					while( (nx = read(fd,msg,sizeof(msg))) > 0 ){
+					while( (nx = Read_fd_len_timeout(Send_query_rw_timeout_DYN, fd,msg,sizeof(msg))) > 0 ){
 						if( Write_fd_len(tempfd,msg,nx) < 0 ) cleanup(0);
 					}
 					close(fd); fd = -1;
@@ -1399,7 +1395,7 @@ void Get_local_or_remote_status( struct line_list *tokens, int *sock,
 		if( fd >= 0 ){
 			/* shutdown( fd, 1 ); */
 			tempfd = Make_temp_fd( 0 );
-			while( (n = read(fd,msg,sizeof(msg))) > 0 ){
+			while( (n = Read_fd_len_timeout(Send_query_rw_timeout_DYN, fd,msg,sizeof(msg))) > 0 ){
 				if( Write_fd_len(tempfd,msg,n) < 0 ) cleanup(0);
 			}
 			close(fd); fd = -1;
