@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: lpr.c,v 1.57 2003/09/05 20:07:19 papowell Exp $";
+"$Id: lpr.c,v 1.71 2004/05/03 20:24:03 papowell Exp $";
 
 
 #include "lp.h"
@@ -177,7 +177,7 @@ int main(int argc, char *argv[], char *envp[])
 	/* we do not do any translation of formats */
 	s = 0;
 
-	n = Find_flag_value( &prjob.info,DATAFILE_COUNT,Value_sep);
+	n = Find_flag_value( &prjob.info,DATAFILE_COUNT);
 	if( Max_datafiles_DYN > 0 && n > Max_datafiles_DYN ){
 		Errorcode = 1;
 		FATAL(LOG_INFO) _("%d data files and maximum allowed %d"),
@@ -210,7 +210,7 @@ int main(int argc, char *argv[], char *envp[])
 		if(DEBUGL2) Dump_job( "lpr - before filtering", &prjob );
 		tempfd = Make_temp_fd(&tempfile);
 
-		old_lp_value = safestrdup(Find_str_value( &PC_entry_line_list, "lp", Value_sep ),
+		old_lp_value = safestrdup(Find_str_value( &PC_entry_line_list, "lp"),
 			__FILE__,__LINE__);
 		Set_str_value( &PC_entry_line_list, LP, tempfile );
 		/* Print_job( output_device, status_device, job, timeout, poll_for_status ) */
@@ -241,7 +241,7 @@ int main(int argc, char *argv[], char *envp[])
 	}
 
 	if(DEBUGL1)Dump_job("lpr - before Fix_control",&prjob);
-	Fix_control( &prjob, Control_filter_DYN, 0 );
+	Fix_control( &prjob, Control_filter_DYN, 0, 1 );
 	if(DEBUGL1)Dump_job("lpr - after Fix_control",&prjob);
 
 	if( send_to_pr &&
@@ -263,7 +263,7 @@ int main(int argc, char *argv[], char *envp[])
 			Errorcode = JFAIL;
 			goto exit;
 		}
-		id = Find_str_value(&prjob.info,IDENTIFIER,Value_sep);
+		id = Find_str_value(&prjob.info,IDENTIFIER);
 		SETSTATUS(&prjob)"transferring job '%s'", id );
 		/* Print_job( output_device, status_device, job, timeout, poll_for_status, filter ) */
 		Set_str_value( &PC_entry_line_list, LP, s );
@@ -350,11 +350,11 @@ int main(int argc, char *argv[], char *envp[])
 		char *id;
 		int n;
 		char msg[SMALLBUFFER];
-		id = Find_str_value(&prjob.info,IDENTIFIER,Value_sep);
+		id = Find_str_value(&prjob.info,IDENTIFIER);
 		if( id ){
 			SNPRINTF(msg,sizeof(msg)-1)_("request id is %s\n"), id );
 		} else {
-			n = Find_decimal_value(&prjob.info,NUMBER,Value_sep);
+			n = Find_decimal_value(&prjob.info,NUMBER);
 			SNPRINTF(msg,sizeof(msg)-1)_("request id is %d\n"), n );
 		}
 		Write_fd_str(1, msg );
@@ -991,7 +991,7 @@ int Make_job( struct job *job )
 			then we set it
 		*/
 		if( keys->keyword ){
-			s = Find_str_value(&job->info,*keys->keyword,Value_sep);
+			s = Find_str_value(&job->info,*keys->keyword);
 		}
 		p = keys->variable;
 		nstr[0] = 0;
@@ -1048,6 +1048,7 @@ int Make_job( struct job *job )
 			SNPRINTF(nstr,sizeof(nstr))"%c",Format_JOB);
 			Set_str_value(lp,FORMAT,nstr);
 			Set_double_value(lp,SIZE,0 );
+			Set_str_value(lp,OPENNAME,"-");
 			job_size = 1;	/* make checker happy */
 		} else {
 			job_size = Copy_STDIN( job );
@@ -1126,7 +1127,7 @@ double Copy_STDIN( struct job *job )
 	}
 	DEBUG1("Temporary file '%s', fd %d", tempfile, fd );
 	size = 0;
-	while( (count = read( 0, buffer, sizeof(buffer))) > 0 ){
+	while( (count = ok_read( 0, buffer, sizeof(buffer))) > 0 ){
 		if( write( fd, buffer, count ) < 0 ){
 			Errorcode = JABORT;
 			LOGERR_DIE(LOG_INFO) _("Copy_STDIN: write to temp file failed"));
@@ -1145,7 +1146,7 @@ double Copy_STDIN( struct job *job )
 		job->datafiles.list[job->datafiles.count++] = (void *) lp;
 		Set_str_value(lp,"N","(STDIN)");
 		Set_str_value(lp,OPENNAME,tempfile);
-		Set_str_value(lp,TRANSFERNAME,tempfile);
+		Set_str_value(lp,DFTRANSFERNAME,tempfile);
 		Set_flag_value(lp,COPIES,1);
 		SNPRINTF(buffer,sizeof(buffer))"%c",Format_JOB);
 		Set_str_value(lp,FORMAT,buffer);
@@ -1201,7 +1202,7 @@ double Check_files( struct job *job )
 			Check_max(&job->datafiles,1);
 			job->datafiles.list[job->datafiles.count++] = (void *) lp;
 			Set_str_value(lp,OPENNAME,tempfile);
-			Set_str_value(lp,TRANSFERNAME,s);
+			Set_str_value(lp,DFTRANSFERNAME,s);
 			Clean_meta(s);
 			Set_str_value(lp,"N",s);
 			Set_flag_value(lp,COPIES,1);
@@ -1245,7 +1246,7 @@ int Check_lpr_printable(char *file, int fd, struct stat *statb, int format )
     } else if(statb->st_size == 0) {
 		/* empty file */
 		printable = -1;
-    } else if ((n = read (fd, buf, sizeof(buf))) <= 0) {
+    } else if ((n = ok_read (fd, buf, sizeof(buf))) <= 0) {
         DIEMSG (err, file,_("cannot read it"));
     } else if (format != 'p' && format != 'f' ){
         printable = 1;
