@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: sendjob.c,v 1.57 2003/09/05 20:07:20 papowell Exp $";
+"$Id: sendjob.c,v 1.71 2004/05/03 20:24:03 papowell Exp $";
 
 
 #include "lp.h"
@@ -81,7 +81,7 @@ int Send_job( struct job *job, struct job *logjob,
 	char *real_host = 0, *save_host = 0;
 	int status = 0, err, errcount = 0, n, len;
 	char msg[SMALLBUFFER];
-	char error[LARGEBUFFER];
+	char error[LARGEBUFFER], errmsg[SMALLBUFFER];
 	struct security *security = 0;
 	struct line_list info;
  
@@ -96,8 +96,8 @@ int Send_job( struct job *job, struct job *logjob,
 	Set_flag_value(&job->info,ERROR_TIME,0);
 	/* send job to the LPD server for the RemotePrinter_DYN */
 
-	id = Find_str_value( &job->info,IDENTIFIER,Value_sep);
-	if( id == 0 ) id = Find_str_value( &job->info,TRANSFERNAME,Value_sep);
+	id = Find_str_value( &job->info,IDENTIFIER);
+	if( id == 0 ) id = Find_str_value( &job->info,CFTRANSFERNAME);
 	DEBUG3("Send_job: '%s'->%s@%s,connect(timeout %d,interval %d)",
 		id, RemotePrinter_DYN, RemoteHost_DYN,
 			connect_timeout_len, connect_interval );
@@ -135,16 +135,17 @@ int Send_job( struct job *job, struct job *logjob,
 
 	errno = 0;
 
+	errmsg[0] = 0;
 	sock = Link_open_list( RemoteHost_DYN,
-		&real_host, connect_timeout_len, 0, Unix_socket_path_DYN );
-
+		&real_host, connect_timeout_len, 0, Unix_socket_path_DYN, errmsg, sizeof(errmsg) );
 	err = errno;
+
 	DEBUG4("Send_job: socket %d", sock );
 	if( sock < 0 ){
 		++errcount;
 		status = LINK_OPEN_FAIL;
 		msg[0] = 0;
-		if( !Is_server && err ){
+		if( !Is_server ){
 			SNPRINTF( msg, sizeof(msg))
 			"\nMake sure the remote host supports the LPD protocol");
 			if( geteuid() && getuid() ){
@@ -155,7 +156,7 @@ int Send_job( struct job *job, struct job *logjob,
 		}
 		SNPRINTF( error, sizeof(error)-2)
 			"cannot open connection to %s - %s%s", RemoteHost_DYN,
-				err?Errormsg(err):"bad or missing hostname?", msg );
+				errmsg[0]?errmsg:(err?Errormsg(err):"bad or missing hostname?"), msg );
 		if( Is_server && Retry_NOLINK_DYN ){
 			if( connect_interval > 0 ){
 				n = (connect_interval * (1 << (errcount - 1)));
@@ -204,7 +205,7 @@ int Send_job( struct job *job, struct job *logjob,
 
 	if( sock >= 0 ) sock = Shutdown_or_close(sock);
 	if( status ){
-		if( (s = Find_str_value(&job->info,ERROR,Value_sep )) ){
+		if( (s = Find_str_value(&job->info,ERROR )) ){
 			SETSTATUS(logjob) "job '%s' transfer to %s@%s failed\n  %s",
 				id, RemotePrinter_DYN, RemoteHost_DYN, s );
 			Set_nz_flag_value(&job->info,ERROR_TIME,time(0));
@@ -215,7 +216,8 @@ int Send_job( struct job *job, struct job *logjob,
 			msg[0] = 0;
 			n = 0;
 			while( len < (int)sizeof(msg)-1
-				&& (n = read(sock,msg+len,sizeof(msg)-len-1)) > 0 ){
+				&& (n = Read_fd_len_timeout(Send_job_rw_timeout_DYN,
+					sock,msg+len,sizeof(msg)-len-1)) > 0 ){
 				msg[len+n] = 0;
 				DEBUG2("Send_job: read %d, '%s'", n, msg);
 				while( (s = safestrchr(msg,'\n')) ){
@@ -280,8 +282,8 @@ int Send_normal( int *sock, struct job *job, struct job *logjob,
 	DEBUG3("Send_normal: send_data_first %d, sock %d, block_fd %d",
 		Send_data_first_DYN, *sock, block_fd );
 
-	id = Find_str_value(&job->info,"A",Value_sep);
-	transfername = Find_str_value(&job->info,TRANSFERNAME,Value_sep);
+	id = Find_str_value(&job->info,"A");
+	transfername = Find_str_value(&job->info,CFTRANSFERNAME);
 	
 	if( !block_fd ){
 		SETSTATUS(logjob) "requesting printer %s@%s",
@@ -333,16 +335,12 @@ int Send_control( int *sock, struct job *job, struct job *logjob, int transfer_t
 	 * get the total length of the control file
 	 */
 
-	if( !(cf = Find_str_value(&job->info,CF_OUT_IMAGE,Value_sep)) ){
-		s = Find_str_value(&job->info,OPENNAME,Value_sep);
-		if( !s ) s = Find_str_value(&job->info,TRANSFERNAME,Value_sep);
-		s = Get_file_image( s, 0 );
-		Set_str_value(&job->info, CF_OUT_IMAGE, s );
-		if( s ) free(s); s = 0;
-		cf = Find_str_value(&job->info,CF_OUT_IMAGE,Value_sep);
+	if( !(cf = Find_str_value(&job->info,CF_OUT_IMAGE)) ){
+		Errorcode = JABORT;
+		FATAL(LOG_ERR) "Send_control: LOGIC ERROR! missing CF_OUT_IMAGE");
 	}
 	size = safestrlen(cf);
-	transfername = Find_str_value(&job->info,TRANSFERNAME,Value_sep);
+	transfername = Find_str_value(&job->info,CFTRANSFERNAME);
 
 	DEBUG3( "Send_control: '%s' is %d bytes, sock %d, block_fd %d, cf '%s'",
 		transfername, size, *sock, block_fd, cf );
@@ -434,7 +432,7 @@ int Send_data_files( int *sock, struct job *job, struct job *logjob,
 	int transfer_timeout, int block_fd, char *final_filter )
 {
 	int count, fd, err, status = 0, ack;
-	double size, sendsize;
+	double size;
 	struct line_list *lp;
 	char *openname, *transfername, *id, *s;
 	char msg[SMALLBUFFER];
@@ -442,27 +440,35 @@ int Send_data_files( int *sock, struct job *job, struct job *logjob,
 	struct stat statb;
 
 	DEBUG3( "Send_data_files: data file count '%d'", job->datafiles.count );
-	id = Find_str_value(&job->info,"identification",Value_sep);
-	if( id == 0 ) id = Find_str_value(&job->info,TRANSFERNAME,Value_sep);
+	id = Find_str_value(&job->info,"identification");
+	if( id == 0 ) id = Find_str_value(&job->info,CFTRANSFERNAME);
 	for( count = 0; count < job->datafiles.count; ++count ){
 		lp = (void *)job->datafiles.list[count];
 		if(DEBUGL3)Dump_line_list("Send_data_files - entries",lp);
-		openname = Find_str_value(lp,OPENNAME,Value_sep);
-		transfername = Find_str_value(lp,TRANSFERNAME,Value_sep);
-		DEBUG3("Send_data_files: opening file '%s'", openname );
+		transfername = Find_str_value(lp,DFTRANSFERNAME);
+		openname = Find_str_value(lp,OPENNAME);
+		if( !openname ) openname = transfername;
+		DEBUG3("Send_data_files: opening file '%s', transfername '%s'",
+			openname, transfername );
 
 		/*
 		 * open file as user; we should be running as user
 		 */
-		sendsize = size = 0;
-		if( openname == 0 ){
+		size = 0;
+		if( !strcmp(openname,"-") ){
 			openname = "(STDIN)";
 			fd = 0;
 			size = 0;
-			sendsize = Fake_large_file_DYN * 1024;
 		} else {
 			fd = Checkread( openname, &statb );
-			sendsize = size = statb.st_size;
+			if( fd < 0 ){
+				status = JFAILNORETRY;
+				SNPRINTF(error,sizeof(error))
+					"cannot open '%s' - '%s'", openname, Errormsg(errno) );
+				Set_str_value(&job->info,ERROR,error);
+				Set_nz_flag_value(&job->info,ERROR_TIME,time(0));
+				goto error;
+			}
 			if( statb.st_size == 0 ){
 				SNPRINTF(error,sizeof(error))
 				"zero length file '%s'", transfername );
@@ -471,19 +477,10 @@ int Send_data_files( int *sock, struct job *job, struct job *logjob,
 				Set_nz_flag_value(&job->info,ERROR_TIME,time(0));
 				goto error;
 			}
+			size = statb.st_size;
 		}
 		if( count == job->datafiles.count -1 && final_filter ){
 			size = 0;
-			sendsize = Fake_large_file_DYN * 1024;
-		}
-		err = errno;
-		if( fd < 0 ){
-			status = JFAIL;
-			SNPRINTF(error,sizeof(error))
-				"cannot open '%s' - '%s'", openname, Errormsg(err) );
-			Set_str_value(&job->info,ERROR,error);
-			Set_nz_flag_value(&job->info,ERROR_TIME,time(0));
-			goto error;
 		}
 
 		DEBUG3( "Send_data_files: openname '%s', fd %d, size %0.0f",
@@ -522,7 +519,7 @@ int Send_data_files( int *sock, struct job *job, struct job *logjob,
 			DEBUG3("Send_data_files: transfering '%s', fd %d", openname, fd );
 			ack = 0;
 			if( count == job->datafiles.count-1 && final_filter ){
-				status = Filter_file( fd, *sock, "UserFilter",
+				status = Filter_file( transfer_timeout, fd, *sock, "UserFilter",
 					final_filter, Filter_options_DYN, job, 0, 1 );
 				DEBUG3("Send_data_files: final_filter '%s' status %d", final_filter, status );
 				close(fd); fd = 0;
@@ -564,7 +561,8 @@ int Send_data_files( int *sock, struct job *job, struct job *logjob,
 			}
 			/* now we need to read the file and transfer it */
 			total = 0;
-			while( total < size && (len = read(fd, msg, sizeof(msg)) ) > 0 ){
+			while( total < size && (len = Read_fd_len_timeout(Send_job_rw_timeout_DYN,
+					fd, msg, sizeof(msg))) > 0 ){
 				if( write( block_fd, msg, len ) < 0 ){
 					goto write_error;
 				}
@@ -634,8 +632,8 @@ int Send_block( int *sock, struct job *job, struct job *logjob, int transfer_tim
 	char *id, *transfername, *tempfile;
 
 	error[0] = 0;
-	id = Find_str_value(&job->info,IDENTIFIER,Value_sep);
-	transfername = Find_str_value(&job->info,TRANSFERNAME,Value_sep);
+	id = Find_str_value(&job->info,IDENTIFIER);
+	transfername = Find_str_value(&job->info,CFTRANSFERNAME);
 	if( id == 0 ) id = transfername;
 
 	tempfd = Make_temp_fd( &tempfile );
@@ -643,8 +641,8 @@ int Send_block( int *sock, struct job *job, struct job *logjob, int transfer_tim
 
 	status = Send_normal( &tempfd, job, logjob, transfer_timeout, tempfd, 0 );
 
-	id = Find_str_value(&job->info,IDENTIFIER,Value_sep);
-	transfername = Find_str_value(&job->info,TRANSFERNAME,Value_sep);
+	id = Find_str_value(&job->info,IDENTIFIER);
+	transfername = Find_str_value(&job->info,CFTRANSFERNAME);
 	if( id == 0 ) id = transfername;
 
 	DEBUG1("Send_block: sendnormal of '%s' returned '%s'", id, Server_status(status) );
