@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: ssl_auth.c,v 1.26 2003/09/05 20:07:20 papowell Exp $";
+"$Id: ssl_auth.c,v 1.40 2004/05/03 20:24:03 papowell Exp $";
 
 
 #include "lp.h"
@@ -16,6 +16,8 @@
 #include "errorcodes.h"
 #include "getqueue.h"
 #ifdef SSL_ENABLE
+/* The Kerberos 5 support is MIT-specific. */
+#define OPENSSL_NO_KRB5
 #include <openssl/ssl.h>
 #include <openssl/err.h>
 #include "user_auth.h"
@@ -210,7 +212,7 @@ int SSL_Initialize_ctx(
 				LOGERR_DIE(LOG_ERR) "SSL_initialize: cannot open server_password_file '%s'",
 					file );
 			}
-			if( (n = read(fd, password_value, sizeof(password_value)-1)) < 0 ){
+			if( (n = ok_read(fd, password_value, sizeof(password_value)-1)) < 0 ){
 				Errorcode = JABORT;
 				LOGERR_DIE(LOG_ERR) "SSL_initialize: cannot read server_password_file '%s'",
 					file );
@@ -236,7 +238,7 @@ int SSL_Initialize_ctx(
 		file = getuservals("LPR_SSL_PASSWORD",homedir, ".lpr/client.pwd", pwbuf, sizeof(pwbuf));
 		if( file ) fd = Checkread( file, &statb );
 		if( fd > 0 ){
-			if( (n = read(fd, password_value, sizeof(password_value)-1)) < 0 ){
+			if( (n = ok_read(fd, password_value, sizeof(password_value)-1)) < 0 ){
 				Errorcode = JABORT;
 				LOGERR_DIE(LOG_ERR) "SSL_initialize: cannot read server_password_file '%s'",
 					file );
@@ -333,44 +335,43 @@ void Get_cert_info( SSL *ssl, struct line_list *info )
 {
 	X509 *peer;
 	STACK_OF(X509) *sk;
-	int i;
+	int i, n;
 	char *certs = 0;
 	char buffer[SMALLBUFFER];
 
 	sk=SSL_get_peer_cert_chain(ssl);
-	if( sk && sk_X509_num(sk) ){
-		for( i = 0; i < sk_X509_num(sk); ++i ){
+	if( sk && (n = sk_X509_num(sk)) > 0 ){
+		for( i = n-1; i >= 0; --i ){
 			peer = sk_X509_value(sk,i);
 			if( X509_NAME_oneline( X509_get_subject_name( peer ),
 				buffer, sizeof(buffer) ) ){
-				DEBUG1("Open_SSL_connection: level [%d] subject '%s'", i, buffer );
-				if( i == 0 && info ){
+				DEBUG1("Get_cert_info: level [%d of %d] subject '%s'", i, n, buffer );
+				if( i == n-1 && info ){
 					Set_str_value(info,AUTHFROM,buffer);
 				}
-				if( i ) certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
+				certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
 			}
-			if( X509_NAME_oneline( X509_get_issuer_name( peer ),
+			if( 0 && X509_NAME_oneline( X509_get_issuer_name( peer ),
 				buffer, sizeof(buffer) ) ){
-				DEBUG1("Open_SSL_connection: level [%d] issuer '%s'", i, buffer );
+				DEBUG1("Get_cert_info: level [%d of %d] issuer '%s'", i, n, buffer );
 				certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
 			}
 		}
-	} else {
-		peer = SSL_get_peer_certificate(ssl);
-		if( peer ){
-			if( X509_NAME_oneline( X509_get_subject_name( peer ),
-				buffer, sizeof(buffer) ) ){
-				DEBUG1("Open_SSL_connection: peer subject '%s'", buffer );
-				if( info ){
-					Set_str_value(info,AUTHFROM,buffer);
-				}
-				certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
-			}
-			if( X509_NAME_oneline( X509_get_issuer_name( peer ),
-				buffer, sizeof(buffer) ) ){
-				DEBUG1("Open_SSL_connection: peer issuer '%s'", buffer );
-				certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
+	}
+	peer = SSL_get_peer_certificate(ssl);
+	if( peer ){
+		if( X509_NAME_oneline( X509_get_subject_name( peer ),
+			buffer, sizeof(buffer) ) ){
+			DEBUG1("Get_cert_info: peer subject '%s'", buffer );
+			if( info ){
+				Set_str_value(info,AUTHFROM,buffer);
 			}
+			certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
+		}
+		if( X509_NAME_oneline( X509_get_issuer_name( peer ),
+			buffer, sizeof(buffer) ) ){
+			DEBUG1("Get_cert_info: peer issuer '%s'", buffer );
+			certs = safeextend3( certs, buffer, "\n", __FILE__,__LINE__ );
 		}
 	}
 	if( info ){
@@ -471,13 +472,13 @@ int Accept_SSL_connection( int sock, int timeout, SSL_CTX *ctx, SSL **ssl_ret,
 	int status = 0;
 
 	/* we get the SSL context.  No connection yet */
-	DEBUG1("Accept_ssl_connection: starting, ctx 0x%lx, sock %d", Cast_ptr_to_long(ctx), sock);
+	DEBUG1("Accept_SSL_connection: starting, ctx 0x%lx, sock %d", Cast_ptr_to_long(ctx), sock);
 	
 	ssl = SSL_new(ctx);
-	DEBUG1("Accept_ssl_connection: SSL_new 0x%lx", Cast_ptr_to_long(ssl) );
+	DEBUG1("Accept_SSL_connection: SSL_new 0x%lx", Cast_ptr_to_long(ssl) );
 	if( !ssl ){
 		Set_ERR_str( "Accept_SSL_connection: SSL_new failed", errmsg, errlen );
-		DEBUG1("Accept_ssl_connection: '%s'", errmsg);
+		DEBUG1("Accept_SSL_connection: '%s'", errmsg);
 		status = -1;
 		goto done;
 	}
@@ -487,7 +488,7 @@ int Accept_SSL_connection( int sock, int timeout, SSL_CTX *ctx, SSL **ssl_ret,
 	 */
 	if( !(bio = BIO_new_socket(sock, BIO_NOCLOSE)) ){
 		Set_ERR_str( "Accept_SSL_connection: BIO_new_socket failed", errmsg, errlen );
-		DEBUG1("Accept_ssl_connection: '%s'", errmsg);
+		DEBUG1("Accept_SSL_connection: '%s'", errmsg);
 		status = -1;
 		goto done;
 	}
@@ -495,13 +496,13 @@ int Accept_SSL_connection( int sock, int timeout, SSL_CTX *ctx, SSL **ssl_ret,
 
 	/* if you get any sort of error, give up */
 	finished = wait_for_read = wait_for_write = 0;
-	DEBUG1("Accept_ssl_connection: loop");
+	DEBUG1("Accept_SSL_connection: loop");
 	while(!finished){
 		if( wait_for_read || wait_for_write ){
 			fd_set readfds, writefds, exceptfds;	/* for select() */
 			struct timeval tv, *tm = 0;
 
-			DEBUG1("Accept_ssl_connection: need to wait for IO");
+			DEBUG1("Accept_SSL_connection: need to wait for IO");
 			memset(&tv,0,sizeof(tv));
 			tv.tv_sec = timeout;
 			if( timeout ) tm = &tv;
@@ -598,7 +599,7 @@ int Write_SSL_connection( int timeout, SSL *ssl, char *buffer, int len,
 }
 
 /*
- * get a line termianted with \n into the buffer of size len
+ * get a line terminated with \n into the buffer of size len
  *  - reads at most len-1 chars to make sure a terminating 0
  * can be appended
  *  returns: 0 - success
@@ -658,7 +659,7 @@ int Read_SSL_connection( int timeout, SSL *ssl, char *inbuffer, int *len,
 	Clear_timeout();
 	switch( SSL_get_error( ssl, ret ) ){
 		case SSL_ERROR_NONE:
-			*len = n;
+			*len = ret;
 			break;
 		case SSL_ERROR_ZERO_RETURN:
 			status = 1;
@@ -759,16 +760,16 @@ int Ssl_send( int *sock,
 	size = statb.st_size;
 	SNPRINTF(buffer,sizeof(buffer)) "%0.0f\n", size );
 	DEBUG1("Ssl_send: writing '%s'", buffer );
-	if( Write_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, strlen(buffer), errmsg, errlen) ){
+	if( Write_SSL_connection( transfer_timeout, ssl, buffer, strlen(buffer), errmsg, errlen) ){
 		status = JFAIL;
 		goto t_error;
 	}
 
 	DEBUG1("Ssl_send: starting send");
-	while( (len = read( tempfd, buffer, sizeof(buffer)-1 )) > 0 ){
+	while( (len = ok_read( tempfd, buffer, sizeof(buffer)-1 )) > 0 ){
 		buffer[len] = 0;
 		DEBUG4("Ssl_send: file information '%s'", buffer );
-		if( Write_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, len, errmsg, errlen) ){
+		if( Write_SSL_connection( transfer_timeout, ssl, buffer, len, errmsg, errlen) ){
 			status = JFAIL;
 			goto t_error;
 		}
@@ -791,7 +792,7 @@ int Ssl_send( int *sock,
 	DEBUG1("Ssl_send: sent file" );
 
 	DEBUG1("Ssl_send: getting read size");
-	if( Gets_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, sizeof(buffer), errmsg, errlen) ){
+	if( Gets_SSL_connection( transfer_timeout, ssl, buffer, sizeof(buffer), errmsg, errlen) ){
 		status = JFAIL;
 		goto error;
 	}
@@ -802,7 +803,7 @@ int Ssl_send( int *sock,
 	while( size > 0 ){
 		len = sizeof(buffer)-1;
 		if( len > size ) len = size;
-		if( Read_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, &len, errmsg, errlen) ){
+		if( Read_SSL_connection( transfer_timeout, ssl, buffer, &len, errmsg, errlen) ){
 			status = JFAIL;
 			goto error;
 		}
@@ -846,7 +847,7 @@ int Ssl_send( int *sock,
 	return(status);
 }
 
-int Ssl_receive( int *sock,
+int Ssl_receive( int *sock, int transfer_timeout,
 	char *user, char *jobsize, int from_server, char *authtype,
 	struct line_list *info,
 	char *errmsg, int errlen,
@@ -875,7 +876,7 @@ int Ssl_receive( int *sock,
 		status = JFAIL;
 		goto error;
 	}
-	if( Accept_SSL_connection( *sock, Send_job_rw_timeout_DYN, ctx, &ssl, header_info, errmsg, errlen ) ){
+	if( Accept_SSL_connection( *sock, transfer_timeout, ctx, &ssl, header_info, errmsg, errlen ) ){
 		status = JFAIL;
 		goto error;
 	}
@@ -889,7 +890,7 @@ int Ssl_receive( int *sock,
 	}
 
 	DEBUGF(DRECV1)("Ssl_receive: getting read size");
-	if( Gets_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, sizeof(buffer), errmsg, errlen) ){
+	if( Gets_SSL_connection( transfer_timeout, ssl, buffer, sizeof(buffer), errmsg, errlen) ){
 		status = JFAIL;
 		goto error;
 	}
@@ -899,7 +900,7 @@ int Ssl_receive( int *sock,
 	while( size > 0 ){
 		len = sizeof(buffer);
 		if( len > size ) len = size;
-		if( Read_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, &len, errmsg, errlen) ){
+		if( Read_SSL_connection( transfer_timeout, ssl, buffer, &len, errmsg, errlen) ){
 			status = JFAIL;
 			goto error;
 		}
@@ -934,15 +935,15 @@ int Ssl_receive( int *sock,
 	size = statb.st_size;
 	SNPRINTF(buffer,sizeof(buffer)) "%0.0f\n", size );
 	DEBUG1("Ssl_receive: writing '%s'", buffer );
-	if( Write_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, strlen(buffer), errmsg, errlen) ){
+	if( Write_SSL_connection( transfer_timeout, ssl, buffer, strlen(buffer), errmsg, errlen) ){
 		status = JFAIL;
 		goto error;
 	}
 
-	while( (n = read(tempfd, buffer,sizeof(buffer)-1)) > 0 ){
+	while( (n = ok_read(tempfd, buffer,sizeof(buffer)-1)) > 0 ){
 		buffer[n] = 0;
 		DEBUGF(DRECV1)("Ssl_receive: sending '%d' '%s'", n, buffer );
-		if( Write_SSL_connection( Send_job_rw_timeout_DYN, ssl, buffer, n, errmsg, errlen) ){
+		if( Write_SSL_connection( transfer_timeout, ssl, buffer, n, errmsg, errlen) ){
 			status = JFAIL;
 			goto error;
 		}
