@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: utilities.c,v 1.57 2003/09/05 20:07:20 papowell Exp $";
+"$Id: utilities.c,v 1.71 2004/05/03 20:24:04 papowell Exp $";
 
 #include "lp.h"
 
@@ -85,7 +85,7 @@ char *Pretty_time( time_t t )
 		t = tv.tv_sec;
 	}
 	tmptr = localtime( &t );
-	strftime( buffer, sizeof(buffer), "%b %d %R %Y", tmptr );
+	strftime( buffer, sizeof(buffer), "%b %d %H:%M:%S %Y", tmptr );
 
 	return( buffer );
 }
@@ -222,13 +222,14 @@ int Read_fd_len_timeout( int timeout, int fd, char *msg, int len )
 	if( timeout > 0 ){
 		if( Set_timeout() ){
 			Set_timeout_alarm( timeout  );
-			i = read( fd, msg, len );
+			i = ok_read( fd, msg, len );
 		} else {
 			i = -1;
+			errno = EINTR;
 		}
 		Clear_timeout();
 	} else {
-		i = read( fd, msg, len );
+		i = ok_read( fd, msg, len );
 	}
 	return( i );
 }
@@ -482,21 +483,6 @@ char *safestrpbrk( const char *s1, const char *s2 )
 	return( 0 );
 }
 
-/* perform string concatentaton with malloc */
-char *safestrappend4( char *s1, const char *s2, const char *s3, const char *s4 )
-{
-	int m, len;
-	m = safestrlen(s1);
-	len = m + safestrlen(s2) + safestrlen(s3) + safestrlen(s4);
-	s1 = realloc(s1,len+1);
-	len = m;
-	if( s2 ) strcpy( s1+len, s2 ); len += strlen(s1+len);
-	if( s3 ) strcpy( s1+len, s3 ); len += strlen(s1+len);
-	if( s4 ) strcpy( s1+len, s4 ); len += strlen(s1+len);
-	s1[ len ] = 0;
-	return(s1);
-}
-
 /***************************************************************************
  * plp_usleep() with select - simple minded way to avoid problems
  ***************************************************************************/
@@ -830,7 +816,7 @@ int Read_write_timeout(
 		} else {
 			if( FD_ISSET( readfd, &readfds ) ){
 				DEBUG4("Read_write_timeout: read possible on fd %d", readfd );
-				m = read( readfd, inbuffer, maxinlen );
+				m = ok_read( readfd, inbuffer, maxinlen );
 				DEBUG4("Read_write_timeout: read() returned %d", m );
 				if( readlen ) *readlen = m;
 				/* caller leaves space for this */
