@@ -4,7 +4,7 @@
  * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: lp.h,v 1.57 2003/09/05 20:07:21 papowell Exp $
+ * $Id: lp.h,v 1.71 2004/05/03 20:24:05 papowell Exp $
  ***************************************************************************/
 
 
@@ -267,6 +267,7 @@ EXTERN int Check_for_nonprintable_DYN;	/* lpr check for nonprintable file */
 EXTERN int Check_for_protocol_violations_DYN;	/* check for RFC1179 protocol violations */
 EXTERN char* Chooser_DYN;	/* choose the destination for a load balance queue */
 EXTERN int Chooser_interval_DYN;	/* interval between tests for load balance destination */
+EXTERN int Chooser_scan_queue_DYN;	/* scan the queue */
 EXTERN char* Chooser_routine_DYN;	/* choose the destination for a load balance queue */
 EXTERN int Class_in_status_DYN;	/* Show class in status information */
 EXTERN char* Comment_tag_DYN; /* comment identifying printer (LPQ) */
@@ -287,6 +288,7 @@ EXTERN char* Default_priority_DYN;	/* default priority */
 EXTERN char* Default_remote_host_DYN;
 EXTERN char* Default_tmp_dir_DYN;	/* default temporary file directory */
 EXTERN char* Destinations_DYN; /* printers that a route filter may return and we should query */
+EXTERN int   Discard_large_jobs_DYN;  /* discard jobs that exceed max job size */
 EXTERN int   Done_jobs_DYN;        /* keep the last NN done jobs */
 EXTERN int   Done_jobs_max_age_DYN; /* keep the done jobs for at least max age seconds */
 EXTERN int Direct_DYN;		/* allow LPR to send jobs to a socket */
@@ -341,6 +343,8 @@ EXTERN int Long_number_DYN; /* long job number (6 digits) */
 EXTERN char* Lp_device_DYN; /* device name or lp-pipe command to send output to */
 EXTERN int Lpd_bounce_DYN; /* force LPD to do bounce queue filtering */
 EXTERN char* Lpd_listen_port_DYN; /* lpd listens on this port, "off" does not open port */
+EXTERN char* Ipp_listen_port_DYN; /* lpd listens on this port, "off" does not open port */
+EXTERN char* Ipp_port_DYN; /* ipp protocol port */
 EXTERN char* Lpd_path_DYN; /* LPD path for server use */
 EXTERN char* Lpd_port_DYN;	/* client/lpd connect to remote (non-local) lpd servers on this port */
 EXTERN char* Lpd_printcap_path_DYN;
@@ -353,12 +357,14 @@ EXTERN char* Lpr_opts_DYN;		/* addional options for LPR */
 EXTERN int Lpr_send_try_DYN; /* number of times for lpr to try sending job */
 EXTERN char* Mail_from_DYN;
 EXTERN char* Mail_operator_on_error_DYN;
+
+EXTERN int Max_accounting_file_size_DYN;	/* maximum accounting file size */
 EXTERN int Max_connect_interval_DYN;	/* maximum connect interval */
 EXTERN int Max_copies_DYN; /* maximum copies allowed */
 EXTERN int Max_datafiles_DYN; /* maximum datafiles */
 EXTERN int Max_job_size_DYN; /* maximum job size (1Kb blocks, 0 = unlimited) */
-EXTERN int Max_accounting_file_size_DYN;	/* maximum accounting file size */
 EXTERN int Max_log_file_size_DYN;	/* maximum log file size */
+EXTERN int Max_move_count_DYN;	/* maximum number of moves or forwards */
 EXTERN int Max_servers_active_DYN;	/* maximum number of servers active */
 EXTERN int Max_status_line_DYN; /* maximum status line size */
 EXTERN int Max_status_size_DYN;
@@ -368,6 +374,7 @@ EXTERN int Min_printable_count_DYN; /* minimum printable characters for printabl
 EXTERN int Min_status_size_DYN;
 EXTERN int Minfree_DYN; /* minimum space (Kb) to be left in spool filesystem */
 EXTERN int Minfree_DYN; /**/
+
 EXTERN int Ms_time_resolution_DYN;
 EXTERN int Network_connect_grace_DYN; /* grace period for reconnections */
 EXTERN char* New_debug_DYN; /* debug level set for queue handler */
@@ -383,11 +390,13 @@ EXTERN int Page_length_DYN; /* page length (in lines) */
 EXTERN int Page_width_DYN; /* page width (in characters) */
 EXTERN int Page_x_DYN; /* page width in pixels (horizontal) */
 EXTERN int Page_y_DYN; /* page length in pixels (vertical) */
+EXTERN char* Pc_entries_required_DYN;	/* make sure these entries are in PRINTCAP_ENTRY */
 EXTERN char* Pass_env_DYN;	/* pass these environment variables */
 EXTERN char* Pgp_path_DYN;	/* pgp path */
 EXTERN int Poll_time_DYN; /* force polling job queues */
 EXTERN int Poll_start_interval_DYN; /* interval between trying to start servers */
 EXTERN int Poll_servers_started_DYN; /* maximum servers to start at one time */
+EXTERN char* Ppd_file_DYN;	/* ppd file */
 EXTERN char* Pr_program_DYN; /* pr program for p format */
 EXTERN char* Prefix_Z_DYN; /* prefix -Z options on outgoing or filter*/
 EXTERN char* Prefix_option_to_option_DYN; /* prefix option to option, ie, "z,o" */
@@ -466,4 +475,6 @@ EXTERN char* Xlate_format_DYN;	/* translate format ids on outgoing jobs */
 extern int dmalloc_outfile;
 #endif
 
+#define ok_read read
+
 #endif
